from random import choice

class Look():
    @staticmethod
    def like():
        a = choice(["比基尼","破烂的衣服","JK","西装","东北大花袄","狼皮","虎皮裙","皮衣","军绿大衣","背心","校服","伊斯兰传统蒙面服饰","兜帽卫衣","孔乙己同款长衫","孔乙己时期同款短打","皇帝朝服","大臣朝服","中东悍匪同款服饰","杰哥同款短袖","阿伟同款短袖","牧民藏袍","军中训练服"])
        b = choice(["光腿","白色过膝袜","黑色丝袜","黑色渔网袜","校服裤子","大花袄配套花棉裤","牛仔裤","安全裤","蓝白胖次","军装配套裤子","西服裤子"])
        c = choice(["光脚","小皮鞋","运动鞋","老北京布鞋","军靴","鸿星尔克","兔子头棉拖","人字拖","脚镣","草鞋","木屐","高跟鞋","芭蕾舞鞋","皮鞋"])
        d = choice(["机械手","眼镜","翅膀","机械腿","渔夫帽","面具","眼罩","角","机械尾巴","伤痕","金箍","草帽","斗笠","蜂鸟胸针","大红花","金丝框眼镜","擦汗毛巾"])
        e = choice(["单手剑","长戟/枪","现代枪","斧头","镰刀","锤子","武士刀","弓","双剑","巨剑","扫把","伞","书","弩","钓鱼竿","铲子","旗帜","玩偶","棒球套装","盾牌（方形）","物理学圣剑","吉他","御币","爪子","匕首","砍刀","水果刀","法杖","电线杆","棺材","狼牙棒","铁链","手杖","电吉他","烧火棍","朗吉努斯之枪","西瓜刀","钥匙串","收租本","手机","左轮手枪","史密斯冲锋枪","皮鞭","锄头","粉笔","黑板擦","圆盾","神秘手提箱","拖拉机车钥匙","钢笔"])
        f = choice(["白色","红色","金色","黑色","粉色","灰色","绿色","蓝色"])
        g = choice(["披肩长发","中短发","双马尾","单马尾","丸子头","卷发","杂乱发型","麻花辫","寸头","光头","包租婆卷发","莫西干","蘑菇头"])
        h = choice(["黑色","褐色","蓝色","橙色","红色","绿色","灰色"])
        i = choice(["写轮眼","X形","❤形","正常","普普通通的圆形"])
        j = choice(["没有","A","B","C","D","E","F","G","H"])
        k = choice(["白色","黄色","棕色","黑色","灰色","绿色","蓝色","红色","粉色"])
        l = choice(["大高个","小胖墩儿","瘦小","普通","健硕","巨人","矮人"])
        m = choice(["内向","元气","阴郁","病娇","迷糊","笨蛋","知性","色欲","傲娇","暴躁","分裂型","理智","憨厚","怯懦","疯狂"])
        n = choice(["修女","女仆","护士","学生","人偶","天使","兽娘","恶魔","精灵","亡灵","法师","史莱姆","OL","萝莉","御姐","雇佣兵","律师","囚犯","算命先生","教师","清洁工","宿管阿姨","农民","剑灵","奴隶","坐台小姐","工人","水手","总统","包租婆"])
        
        return f"像一个戴着{d}上身{a}下身{b+c}手上拿着{e}的{f+g+h+i}瞳孔{j}cup{k}皮肤{l}体型的{m+n}。"
        
